@@ -1,7 +1,8 @@
 from . import (
-    example1, example2, example3, example4, example5, example6, example7, example8
+    example1, example2, example3, example4, example5, example6, example7, example8, example9
 )
-from ..scene import SceneManager
+from ..scenes import SceneManager
+from .. import Logger
 
 import sys
 
@@ -14,6 +15,7 @@ example_list = [
     example6,
     example7,
     example8,
+    example9,
 ]
 
 def show():
@@ -23,7 +25,7 @@ def show():
         num = int(sys.argv[1])
     if not num:
         for index, example in enumerate(example_list):
-            print("\nExample", index + 1)
+            Logger.Log("\nExample", str(index + 1))
             example.main()
             SceneManager.RemoveScene(SceneManager.GetSceneByName("Scene"))
     else:
